/****************************************************************************
 Module
   DunkButtonService.c

 Revision
   1.0.1

 Description
   This is a module for implementing the dunk button switch debounce

 Notes

 History
 When           Who     What/Why
 -------------- ---     --------
 01/15/12 11:12 jec      revisions for Gen2 framework
 11/07/11 11:26 jec      made the queue static
 10/30/11 17:59 jec      fixed references to CurrentEvent in RunTemplateSM()
 10/23/11 18:20 jec      began conversion from SMTemplate.c (02/20/07 rev)
****************************************************************************/
/*----------------------------- Include Files -----------------------------*/
/* include header files for this state machine as well as any machines at the
   next lower level in the hierarchy that are sub-machines to this machine
*/
#include "ES_Configure.h"
#include "ES_Framework.h"
#include "LoadButton.h"
#include "PIC32_Port_HAL.h"
#include "TestHarnessService.h"
#include "LeaderService.h"

/*----------------------------- Module Defines ----------------------------*/
#define DEBOUNCE_TIME 10
/*---------------------------- Module Functions ---------------------------*/
/* prototypes for private functions for this machine.They should be functions
   relevant to the behavior of this state machine
*/

/*---------------------------- Module Variables ---------------------------*/
// everybody needs a state variable, you may need others as well.
// type of state variable should match htat of enum in header file

static uint8_t LastLoadButtonState;

/*------------------------------ Module Code ------------------------------*/
/****************************************************************************/

bool InitLoadButton(void){
     // Init pin
    PortSetup_ConfigureDigitalInputs(_Port_B, _Pin_9);
  
    // set initial state to closed
    LastLoadButtonState = 0;
}

bool CheckLoadButtonPress(void) {
    bool returnVal = false;
    uint8_t CurrentLoadButtonState = PORTBbits.RB9; // read current button value
    // if the button is currently 1, then it has been pressed down
    if(CurrentLoadButtonState != LastLoadButtonState && CurrentLoadButtonState == 1){
        ES_Event_t newButtonEvent;
        newButtonEvent.EventParam = 0;
        returnVal = true;
        
        ES_Event_t newButtonPress;
        newButtonPress.EventType = HW_BUTTONPRESS;
        newButtonPress.EventParam = 0;
        PostTestHarnessService(newButtonPress);
        
        ES_Event_t enterLoadMode;
        enterLoadMode.EventType = HW_LOADMODE;
        PostLeaderService(enterLoadMode);
    }
    LastLoadButtonState = CurrentLoadButtonState;
    return returnVal;
}
/***************************************************************************
 private functions
 ***************************************************************************/

