/****************************************************************************
 Module
   ServoService.c
 ****************************************************************************/
/*----------------------------- Include Files -----------------------------*/

#include "ES_Configure.h"
#include "ES_Framework.h"
#include "ES_DeferRecall.h"
#include "ServoService.h"
#include "sys/attribs.h"
#include "PIC32_Port_HAL.h"
#include "EyeColor.h"
#include "PWM_PIC32.h"

/*----------------------------- Module Defines ----------------------------*/
#define TICS_PER_MS 2500

#define FULL_CW ((uint16_t)(0.5*TICS_PER_MS))
#define FULL_CCW ((uint16_t)(2.25*TICS_PER_MS))
#define MID_POINT (FULL_CW+((FULL_CCW-FULL_CW)/2))
#define EYEBROW_SCALAR 0.3


/*---------------------------- Module Functions ---------------------------*/

/*---------------------------- Module Variables ---------------------------*/
static uint8_t MyPriority;

static ES_Event_t DeferralQueue[5 + 1];

static int ServoStatus[4] = {0, 1, 0, 0}; // 0 = CW, 1 = CCW {L, R, X, D}
/*------------------------------ Module Code ------------------------------*/

bool InitServoService(uint8_t Priority) {
    ES_Event_t ThisEvent;
    
    MyPriority = Priority;
    ES_InitDeferralQueueWith(DeferralQueue, ARRAY_SIZE(DeferralQueue));
    
    printf("Initializing Servo Service...\r\n");
    
    PWMSetup_BasicConfig(4);
    PWMSetup_SetFreqOnTimer(50, _Timer2_);
    PWMSetup_AssignChannelToTimer(SERVO_BROW_L, _Timer2_);
    PWMSetup_AssignChannelToTimer(SERVO_BROW_R, _Timer2_);
    PWMSetup_AssignChannelToTimer(SERVO_DUNK, _Timer2_);
    PWMSetup_MapChannelToOutputPin(SERVO_BROW_L, PWM_RPB3); // OC1, 7
    PWMSetup_MapChannelToOutputPin(SERVO_BROW_R, PWM_RPB11); // OC2, 22
    PWMSetup_MapChannelToOutputPin(SERVO_DUNK, PWM_RPB2); // OC4, 6
    PWMOperate_SetDutyOnChannel(50, SERVO_BROW_L);
    PWMOperate_SetDutyOnChannel(50, SERVO_BROW_R);
    PWMOperate_SetDutyOnChannel(50, SERVO_DUNK);
    PWMOperate_SetPulseWidthOnChannel(FULL_CW, SERVO_BROW_L);
    PWMOperate_SetPulseWidthOnChannel(FULL_CCW, SERVO_BROW_R);
    PWMOperate_SetPulseWidthOnChannel(FULL_CW, SERVO_DUNK);

    ThisEvent.EventType = ES_INIT;
    if (ES_PostToService(MyPriority, ThisEvent) == true) {
        return true;
    } else {
        return false;
    }
}

bool PostServoService(ES_Event_t ThisEvent) {
    return ES_PostToService(MyPriority, ThisEvent);
}

ES_Event_t RunServoService(ES_Event_t ThisEvent) {
    ES_Event_t ReturnEvent;
    ReturnEvent.EventType = ES_NO_EVENT;
    
    if (ThisEvent.EventType == HW_TOGGLE_SERVO) {
        uint16_t ServoIndex = ThisEvent.EventParam;
        if (ServoStatus[ServoIndex - 1]) {
            if(ServoIndex == SERVO_DUNK){
                PWMOperate_SetPulseWidthOnChannel(FULL_CW, ServoIndex);
            }else{
                PWMOperate_SetPulseWidthOnChannel(FULL_CW * EYEBROW_SCALAR, ServoIndex);
            }
        } else {
            if(ServoIndex == SERVO_DUNK){
                PWMOperate_SetPulseWidthOnChannel(FULL_CCW, ServoIndex);
            }else{
                PWMOperate_SetPulseWidthOnChannel(FULL_CCW * EYEBROW_SCALAR, ServoIndex);
            }
            
        }
        ServoStatus[ServoIndex - 1] = !ServoStatus[ServoIndex - 1];
    }
    return ReturnEvent;
}

/***************************************************************************
 private functions
 ***************************************************************************/

/*------------------------------ End of file ------------------------------*/