/****************************************************************************
 Module
   TestHarnessService.c

 Revision
   1.0.1

 Description
   This is a template file for implementing a simple service under the
   Gen2 Events and Services Framework.

 Notes

 History
 When           Who     What/Why
 -------------- ---     --------
 01/16/12 09:58 jec      began conversion from TemplateFSM.c
****************************************************************************/
/*----------------------------- Include Files -----------------------------*/
/* include header files for this state machine as well as any machines at the
   next lower level in the hierarchy that are sub-machines to this machine
*/
#include "ES_Configure.h"
#include "ES_Framework.h"
#include "TemplateService.h"
#include "SPIQueryLeaderService.h"
#include "BeaconService.h"
#include "PIC32_SPI_HAL.h"
#include "EyeColor.h"
#include <string.h>
#include "ServoService.h"

/*----------------------------- Module Defines ----------------------------*/
#define PRINT_TIME 100
/*---------------------------- Module Functions ---------------------------*/
/* prototypes for private functions for this service.They should be functions
   relevant to the behavior of this service
*/

/*---------------------------- Module Variables ---------------------------*/
// with the introduction of Gen2, we need a module level Priority variable
static uint8_t MyPriority;

/*------------------------------ Module Code ------------------------------*/
/****************************************************************************
 Function
     InitTemplateService

 Parameters
     uint8_t : the priorty of this service

 Returns
     bool, false if error in initialization, true otherwise

 Description
     Saves away the priority, and does any
     other required initialization for this service
 Notes

 Author
     J. Edward Carryer, 01/16/12, 10:00
****************************************************************************/
bool InitTestHarnessService(uint8_t Priority)
{
  ES_Event_t ThisEvent;
  
  MyPriority = Priority;
  /********************************************
   in here you write your initialization code
   *******************************************/
  // post the initial transition event
  ThisEvent.EventType = ES_INIT;
  if (ES_PostToService(MyPriority, ThisEvent) == true)
  {
    return true;
  }
  else
  {
    return false;
  }
}

/****************************************************************************
 Function
     PostTemplateService

 Parameters
     EF_Event_t ThisEvent ,the event to post to the queue

 Returns
     bool false if the Enqueue operation failed, true otherwise

 Description
     Posts an event to this state machine's queue
 Notes

 Author
     J. Edward Carryer, 10/23/11, 19:25
****************************************************************************/
bool PostTestHarnessService(ES_Event_t ThisEvent)
{
  return ES_PostToService(MyPriority, ThisEvent);
}

/****************************************************************************
 Function
    RunTemplateService

 Parameters
   ES_Event_t : the event to process

 Returns
   ES_Event, ES_NO_EVENT if no error ES_ERROR otherwise

 Description
   add your description here
 Notes

 Author
   J. Edward Carryer, 01/15/12, 15:23
****************************************************************************/
ES_Event_t RunTestHarnessService(ES_Event_t ThisEvent)
{
    ES_Event_t ReturnEvent;
    ReturnEvent.EventType = ES_NO_EVENT; // assume no errors
    
    switch(ThisEvent.EventType){
        case ES_INIT:
            ES_Timer_InitTimer(TEST_HARNESS_TIMER, PRINT_TIME);
            break;
        case ES_TIMEOUT:
            ES_Timer_InitTimer(TEST_HARNESS_TIMER, PRINT_TIME);
            //        printf("button value: %d\n", PORTBbits.RB9);
            break;
        case EV_NEW_KEY:{
            switch(ThisEvent.EventParam){
                case 'b':// beacon event
                    SPIOperate_SPI1_Send8(0x01);
                    printf("sent beacon event\r\n");
                    break;
                case 'd': // dunk mode
                    SPIOperate_SPI1_Send8(0x02);
                    printf("sent dunk event\r\n");
                    break;
                case 'l': // load mode
                    SPIOperate_SPI1_Send8(0x03);
                    printf("sent load event\r\n");
                    break;
                case 'c': // dunk complete
                    SPIOperate_SPI1_Send8(0x05);
                    printf("sent dunk complete event\r\n");
                    break;
                case 'r':
                    ChangeEyeColor(RED);
                    break;
                case 't':
                    ChangeEyeColor(BLUE);
                    break;
                case 'q':
                {
                    ES_Event_t ToggleEvent1 = {HW_TOGGLE_SERVO, SERVO_BROW_L};
                    PostServoService(ToggleEvent1);
                    ES_Event_t ToggleEvent2 = {HW_TOGGLE_SERVO, SERVO_BROW_R};
                    PostServoService(ToggleEvent2);
                    ES_Event_t ToggleEvent3 = {HW_TOGGLE_SERVO, SERVO_DUNK};
                    PostServoService(ToggleEvent3);
                }
                break;
                case 'k': // send dunk
                    SPIOperate_SPI1_Send8(0x02);
                    break;
                case 'v': // send load
                    SPIOperate_SPI1_Send8(0x02);
                    break;
                            
                default: // No Event
                    SPIOperate_SPI1_Send8(0xFF);
                    printf("sent no event\r\n");
                    break;
            }
        }
        break;
        case HW_BUTTONPRESS:
        {
            char * whichButton = ThisEvent.EventParam == 1 ? "Dunk" : "Load";
            printf("received button press from %s button\r\n", whichButton);
        }
        break;
            
    }
    
    return ReturnEvent;
}

/***************************************************************************
 private functions
 ***************************************************************************/

/*------------------------------- Footnotes -------------------------------*/
/*------------------------------ End of file ------------------------------*/

